@@ -6,6 +6,8 @@
 */
 
 #include "alarmdialog.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "editorconfig.h"
 #include "ui_alarmdialog.h"
 
@@ -44,7 +46,7 @@ AlarmDialog::AlarmDialog(KCalendarCore::Incidence::IncidenceType incidenceType,
     }
 
     mUi->mOffsetUnit->setCurrentIndex(defaultReminderUnits);
-    mUi->mSoundFile->setMimeTypeFilters({QStringLiteral("audio/x-wav"), QStringLiteral("audio/x-mp3"), QStringLiteral("application/ogg")});
+    mUi->mSoundFile->setMimeTypeFilters({u"audio/x-wav"_s, u"audio/x-mp3"_s, QStringLiteral("application/ogg")});
 
     if (IncidenceEditorNG::EditorConfig::instance()->defaultAudioFileReminders()) {
         mUi->mSoundFile->setUrl(IncidenceEditorNG::EditorConfig::instance()->audioFilePath());
@@ -86,8 +88,7 @@ void AlarmDialog::load(const KCalendarCore::Alarm::Ptr &alarm)
     mUi->mBeforeAfter->setCurrentIndex(beforeafterpos);
 
     offset = offset / 60; // make minutes
-    int useoffset = offset;
-
+    int useoffset;
     if (offset % (24 * 60) == 0 && offset > 0) { // divides evenly into days?
         useoffset = offset / (24 * 60);
         mUi->mOffsetUnit->setCurrentIndex(2);
