@@ -8,12 +8,14 @@
 */
 
 #include "conflictresolver.h"
+using namespace Qt::Literals::StringLiterals;
+
 #include "incidenceeditor_debug.h"
 #include <CalendarSupport/FreeBusyItemModel>
 
 #include <QDate>
 
-static const int DEFAULT_RESOLUTION_SECONDS = 15 * 60; // 15 minutes, 1 slot = 15 minutes
+static constexpr int DEFAULT_RESOLUTION_SECONDS = 15 * 60; // 15 minutes, 1 slot = 15 minutes
 
 using namespace IncidenceEditorNG;
 
@@ -363,6 +365,7 @@ void ConflictResolver::findAllFreeSlots()
         if (summed[i] == 0) {
             ++free_count;
         }
+        /* cppcheck-suppress knownConditionTrueFalse */
         if (summed[i] != 0 || (i == (range - 1) && summed[i] == 0)) {
             // current slot is not free, so push the previous free blocks
             // OR we are in the last slot and it is free
@@ -388,9 +391,7 @@ void ConflictResolver::findAllFreeSlots()
                 // push the free block onto the list
                 mAvailableSlots << KCalendarCore::Period(freeBegin, freeEnd);
                 free_count = 0;
-                if (!free_found) {
-                    free_found = true;
-                }
+                free_found = true;
             }
         }
     }
