@@ -55,10 +55,9 @@ public:
     Akonadi::Monitor *mItemMonitor = nullptr;
     ItemEditorUi *mItemUi = nullptr;
     bool mIsCounterProposal = false;
-    EditorItemManager::SaveAction currentAction;
+    EditorItemManager::SaveAction currentAction{EditorItemManager::None};
     Akonadi::IncidenceChanger *mChanger = nullptr;
 
-public:
     ItemEditorPrivate(Akonadi::IncidenceChanger *changer, EditorItemManager *qq);
     void itemChanged(const Akonadi::Item &, const QSet<QByteArray> &);
     void itemFetchResult(KJob *job);
@@ -74,7 +73,7 @@ public:
 
 ItemEditorPrivate::ItemEditorPrivate(Akonadi::IncidenceChanger *changer, EditorItemManager *qq)
     : q_ptr(qq)
-    , currentAction(EditorItemManager::None)
+
 {
     mFetchScope.fetchFullPayload();
     mFetchScope.setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
@@ -233,7 +232,7 @@ void ItemEditorPrivate::itemChanged(const Akonadi::Item &item, const QSet<QByteA
 {
     Q_Q(EditorItemManager);
     if (mItemUi->containsPayloadIdentifiers(partIdentifiers)) {
-        QPointer<QMessageBox> dlg = new QMessageBox; // krazy:exclude=qclasses
+        QPointer<QMessageBox> dlg = new QMessageBox;
         dlg->setIcon(QMessageBox::Question);
         dlg->setInformativeText(
             i18n("The item has been changed by another application.\n"
