@@ -86,7 +86,7 @@ private:
     void slotConflictResolverAttendeeRemoved(const QModelIndex &index, int first, int last);
     void slotConflictResolverAttendeeChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
     void slotConflictResolverLayoutChanged();
-    void slotFreeBusyAdded(const QModelIndex &index, int first, int last);
+    void slotFreeBusyAdded(const QModelIndex &parent, int first, int last);
     void slotFreeBusyChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
     void updateFBStatus();
     void updateFBStatus(const KCalendarCore::Attendee &attendee, const KCalendarCore::FreeBusy::Ptr &fb);
@@ -124,15 +124,15 @@ private:
     QWidget *mParentWidget = nullptr;
     ConflictResolver *mConflictResolver = nullptr;
 
-    IncidenceDateTime *mDateTime = nullptr;
+    IncidenceDateTime *const mDateTime;
     QString mOrganizer;
 
     /** used dataModel to rely on*/
     AttendeeTableModel *mDataModel = nullptr;
     AttendeeLineEditDelegate *mAttendeeDelegate = nullptr;
     AttendeeComboBoxDelegate *const mStateDelegate;
-    AttendeeComboBoxDelegate *mRoleDelegate = nullptr;
-    AttendeeComboBoxDelegate *mResponseDelegate = nullptr;
+    AttendeeComboBoxDelegate *const mRoleDelegate;
+    AttendeeComboBoxDelegate *const mResponseDelegate;
 
     // the QString is Attendee::uid here
     QMap<QString, KContacts::ContactGroup> mGroupList;
