@@ -62,7 +62,7 @@ static void setExDateTimesFromExDates(KCalendarCore::Recurrence *r, const KCalen
     const auto incidenceTz = r->startDateTime().timeZone();
     QDateTime dt = r->startDateTime().toLocalTime();
     dts.reserve(exDates.count());
-    // The exDates are always in local timezone, but the recurrence might be ocurring on a diffrent day
+    // The exDates are always in local timezone, but the recurrence might be occurring on a different day
     // in the incidence original timezone, so make sure to convert the date
     for (const auto &e : exDates) {
         dt.setDate(e);
@@ -132,7 +132,7 @@ KLocalizedString IncidenceRecurrence::subsOrdinal(const KLocalizedString &text,
         "translate this as \"1\" if just the number itself "
         "should be substituted (1, 22, 123).",
         "0");
-    if (q == QLatin1Char('0')) {
+    if (q == u'0') {
         const QString ordinal = numberToString(number);
         return text.subs(ordinal);
     } else {
@@ -410,7 +410,8 @@ bool IncidenceRecurrence::isDirty() const
         }
     } else {
         KCalendarCore::DateList dates;
-        for (const auto &dt : recurrence->exDateTimes()) {
+        const auto exDts = recurrence->exDateTimes();
+        for (const auto &dt : exDts) {
             dates.append(dt.toLocalTime().date());
         }
         if (mExceptionDates != dates) {
@@ -606,19 +607,19 @@ void IncidenceRecurrence::handleRecurrenceTypeChange(int currentIndex)
     switch (currentIndex) {
     case 2:
         labelFreq = i18ncp("repeat every N >weeks<", "week", "weeks", frequency);
-        freqKey = QLatin1Char('w');
+        freqKey = u'w';
         break;
     case 3:
         labelFreq = i18ncp("repeat every N >months<", "month", "months", frequency);
-        freqKey = QLatin1Char('m');
+        freqKey = u'm';
         break;
     case 4:
         labelFreq = i18ncp("repeat every N >years<", "year", "years", frequency);
-        freqKey = QLatin1Char('y');
+        freqKey = u'y';
         break;
     default:
         labelFreq = i18ncp("repeat every N >days<", "day", "days", frequency);
-        freqKey = QLatin1Char('d');
+        freqKey = u'd';
     }
 
     const QString labelEvery = ki18ncp(
@@ -628,7 +629,7 @@ void IncidenceRecurrence::handleRecurrenceTypeChange(int currentIndex)
                                    "every",
                                    "every")
                                    .subs(frequency)
-                                   .inContext(QStringLiteral("type"), freqKey)
+                                   .inContext(u"type"_s, freqKey)
                                    .toString();
     mUi->mFrequencyLabel->setText(labelEvery);
     mUi->mRecurrenceRuleLabel->setText(labelFreq);
@@ -747,16 +748,8 @@ QString IncidenceRecurrence::numberToString(int number) const
     // The code in here was adapted from an article by Johnathan Wood, see:
     // http://www.blackbeltcoder.com/Articles/strings/converting-numbers-to-ordinal-strings
 
-    static QString _numSuffixes[] = {QStringLiteral("th"),
-                                     QStringLiteral("st"),
-                                     QStringLiteral("nd"),
-                                     QStringLiteral("rd"),
-                                     QStringLiteral("th"),
-                                     QStringLiteral("th"),
-                                     QStringLiteral("th"),
-                                     QStringLiteral("th"),
-                                     QStringLiteral("th"),
-                                     QStringLiteral("th")};
+    /* cppcheck-suppress constVariable */
+    static QString _numSuffixes[] = {u"th"_s, u"st"_s, u"nd"_s, u"rd"_s, u"th"_s, u"th"_s, u"th"_s, u"th"_s, u"th"_s, u"th"_s};
 
     int i = (number % 100);
     int j = (i > 10 && i < 20) ? 0 : (number % 10);
@@ -970,6 +963,7 @@ QBitArray IncidenceRecurrence::weekday() const
 
 int IncidenceRecurrence::weekdayCountForMonth(const QDate &date) const
 {
+    /* cppcheck-suppress assertWithSideEffect */
     Q_ASSERT(date.isValid());
     // This methods returns how often the weekday specified by @param date occurs
     // in the month represented by @param date.
