@@ -8,8 +8,6 @@
 
 #include "kweekdaycheckcombo.h"
 
-#include "incidenceeditor_debug.h"
-
 #include <QLocale>
 
 using namespace IncidenceEditorNG;
@@ -87,3 +85,5 @@ void KWeekdayCheckCombo::setDays(const QBitArray &days, const QBitArray &disable
     }
     setCheckedItems(checkedDays);
 }
+
+#include "moc_kweekdaycheckcombo.cpp"
